=======
History
=======

0.2.1 (2018-04-21)
------------------

* Minor fixes.


0.2.0 (2017-09-25)
------------------

* Moved to Github: https://github.com/paulross/TotalDepth
* First release on PyPI.

0.1.0 (2012-03-03)
------------------

* First release on Sourceforge: https://sourceforge.net/projects/TotalDepth/ registered: 2011-10-02

Earlier versions (unreleased):

* OpenLis - 2010-11-11 to 2011-08-01
* PyLis - 2009 to 2010

